""" Unit test of yaccounts package"""

import unittest
import yaml

from yaccounts import CsvDataAnalyzer


class TestBalances(unittest.TestCase):
    def test_balances(self):
        aa = CsvDataAnalyzer("test/data.csv")

        # Load balances yml file
        with open("test/balances.yml") as yaml_file:
            balance_data = yaml.safe_load(yaml_file)

        aa.run()

        for item in balance_data:
            operating_unit = str(item["operating_unit"])
            year = item["year"]
            balance = item["balance"]

            matches = aa.find(operating_unit, year)

            assert int(matches[0].balance) == int(balance)



CODES_STUDENT_WAGES = (
    5510,
    5599,
    5610,
    5720,
    5812,
    5980,
    5572,
    5570,
    5672,
    5670,
    5600,
    5699,
    5750,
    5950,
    5960,
    8905,
)
CODES_STUDENT_BENEFITS = (5999,)
CODES_STUDENT_TUITION = (6300, 6303, 6304, 6309, 6319, 6390)
CODES_FACULTY_SPRING_SUMMER = (5920, 5260, 5220)
CODES_TRAVEL = (6190, 7000, 7010, 7030, 7050, 7060, 7070, 7080)
CODES_SUPPLIES = (
    2200,
    6000,
    6005,
    6100,
    6109,
    6110,
    6120,
    6125,
    6130,
    6140,
    6160,
    6180,
    6185,
    6192,
    6200,
    6210,
    6220,
    6250,
    6255,
    6270,
    6403,
    6405,
    6600,
    6610,
    6480,
    6490,
    6499,
    8940,
)
CODES_CAPITAL = (1625, 1725, 8930, 9126, 9127, 9136, 9137)
CODES_OVERHEAD = (8990, 8991)

CODES_INTEREST = (4711,)
# CODES_BALANCE_FORWARD = (10, 30)
CODES_INCOME = (
    3500,
    4200,
    5970,
    9250,
    9260,
)

# CODES_BUDGET_ONLY = (10,)
CODES_IGNORED = (30, 1010, 1235, 2000, 2210, 4220, 5700)

COL_NAME_AMOUNT = "JRNL Monetary Amount -no scrn aggregation"

COLOR_STUDENT_WAGES = "rosybrown"
COLOR_STUDENT_BENEFITS = "moccasin"
COLOR_STUDENT_TUITION = "moccasin"
COLOR_FACULTY = "lightskyblue"
COLOR_TRAVEL = "plum"
COLOR_SUPPLIES = "khaki"
COLOR_CAPITAL = "khaki"
COLOR_OVERHEAD = "silver"
COLOR_TOTAL_EXPENSES = "tomato"
COLOR_TOTAL_INCOME = "limegreen"


def all_expense_codes():
    return (
        CODES_STUDENT_WAGES
        + CODES_STUDENT_BENEFITS
        + CODES_STUDENT_TUITION
        + CODES_FACULTY_SPRING_SUMMER
        + CODES_TRAVEL
        + CODES_SUPPLIES
        + CODES_OVERHEAD
        + CODES_CAPITAL
    )


def all_handled_codes():
    return all_expense_codes() + CODES_INTEREST + CODES_IGNORED + CODES_INCOME
